Enum bluez_async::AdapterEvent [−][src]
#[non_exhaustive]
pub enum AdapterEvent {
Powered {
powered: bool,
},
Discovering {
discovering: bool,
},
}Expand description
Details of an event related to a Bluetooth adapter.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The adapter has been powered on or off.
Fields of Powered
powered: boolThe adapter has started or stopped scanning for devices.
Fields of Discovering
discovering: boolTrait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.