Enum bluez_async::BluetoothError [−][src]
pub enum BluetoothError {
NoBluetoothAdapters,
DbusError(Error),
XmlParseError(Error),
UuidNotFound {
uuid: Uuid,
},
UuidParseError(Error),
FlagParseError(String),
AddressTypeParseError(String),
RequiredPropertyMissing(&'static str),
ServiceDiscoveryTimedOut,
MacAddressParseError(ParseMacAddressError),
ModaliasParseError(ParseModaliasError),
}Expand description
An error carrying out a Bluetooth operation.
Variants
No Bluetooth adapters were found on the system.
DbusError(Error)There was an error talking to the BlueZ daemon over D-Bus.
Tuple Fields of DbusError
0: ErrorXmlParseError(Error)Error parsing XML for introspection.
Tuple Fields of XmlParseError
0: ErrorNo service or characteristic was found for some UUID.
Fields of UuidNotFound
uuid: UuidUuidParseError(Error)Error parsing a UUID from a string.
Tuple Fields of UuidParseError
0: ErrorFlagParseError(String)Error parsing a characteristic flag from a string.
Tuple Fields of FlagParseError
0: StringAddressTypeParseError(String)Error parsing an AddressType from a string.
Tuple Fields of AddressTypeParseError
0: StringRequiredPropertyMissing(&'static str)A required property of some device or other object was not found.
Tuple Fields of RequiredPropertyMissing
0: &'static strService discovery didn’t happen within the time limit.
MacAddressParseError(ParseMacAddressError)Error parsing a MacAddress from a string.
Tuple Fields of MacAddressParseError
ModaliasParseError(ParseModaliasError)Error parsing a Modalias from a string.
Tuple Fields of ModaliasParseError