Struct bluez_async::AdapterInfo
source · [−]pub struct AdapterInfo {
pub id: AdapterId,
pub mac_address: MacAddress,
pub address_type: AddressType,
pub name: String,
pub alias: String,
pub modalias: Modalias,
pub powered: bool,
pub discovering: bool,
}Expand description
Information about a Bluetooth adapter on the system.
Fields
id: AdapterIdAn opaque identifier for the adapter. This can be used to perform operations on it.
mac_address: MacAddressThe MAC address of the adapter.
address_type: AddressTypeThe type of MAC address the adapter uses.
name: StringThe Bluetooth system hostname.
alias: StringThe Bluetooth friendly name. This defaults to the system hostname.
modalias: ModaliasInformation about the Bluetooth adapter, mostly useful for debug purposes.
powered: boolWhether the adapter is currently turned on.
discovering: boolWhether the adapter is currently discovering devices.