CharacteristicInfo

Struct CharacteristicInfo 

pub struct CharacteristicInfo {
    pub id: CharacteristicId,
    pub uuid: Uuid,
    pub flags: CharacteristicFlags,
    pub mtu: Option<u16>,
}
Information about a GATT characteristic on a Bluetooth device.

Fields

id: CharacteristicId

An opaque identifier for the characteristic on the device, including a reference to which adapter it was discovered on.

uuid: Uuid

The 128-bit UUID of the characteristic.

flags: CharacteristicFlags

The set of flags (a.k.a. properties) of the characteristic, defining how the characteristic can be used.

mtu: Option<u16>

Characteristic MTU.

This is valid both for ReadValue and WriteValue, but either method can use long procedures when supported.