DeviceInfo

Struct DeviceInfo 

pub struct DeviceInfo {
Show 22 fields pub id: DeviceId, pub mac_address: MacAddress, pub address_type: AddressType, pub name: Option<String>, pub appearance: Option<u16>, pub services: Vec<Uuid>, pub paired: bool, pub connected: bool, pub rssi: Option<i16>, pub tx_power: Option<i16>, pub manufacturer_data: HashMap<u16, Vec<u8>>, pub service_data: HashMap<Uuid, Vec<u8>>, pub services_resolved: bool, pub alias: Option<String>, pub class: Option<u32>, pub bonded: bool, pub icon: Option<String>, pub trusted: bool, pub blocked: bool, pub legacy_pairing: bool, pub modalias: Option<String>, pub wake_allowed: bool,
}
Information about a Bluetooth device which was discovered. See https://git.kernel.org/pub/scm/bluetooth/bluez.git/tree/doc/device-api.txt

Fields

id: DeviceId

An opaque identifier for the device, including a reference to which adapter it was discovered on. This can be used to connect to it.

mac_address: MacAddress

The MAC address of the device.

address_type: AddressType

The type of MAC address the device uses.

name: Option<String>

The human-readable name of the device, if available. Use the Alias property instead.

appearance: Option<u16>

The appearance of the device, as defined by GAP.

services: Vec<Uuid>

The GATT service UUIDs (if any) from the device’s advertisement or service discovery.

Note that service discovery only happens after a connection has been made to the device, but BlueZ may cache the list of services after it is disconnected.

paired: bool

Whether the device is currently paired with the adapter.

connected: bool

Whether the device is currently connected to the adapter.

rssi: Option<i16>

The Received Signal Strength Indicator of the device advertisement or inquiry.

tx_power: Option<i16>

The transmission power level advertised by the device.

manufacturer_data: HashMap<u16, Vec<u8>>

Manufacturer-specific advertisement data, if any. The keys are ‘manufacturer IDs’.

service_data: HashMap<Uuid, Vec<u8>>

The GATT service data from the device’s advertisement, if any. This is a map from the service UUID to its data.

services_resolved: bool

Whether service discovery has finished for the device.

alias: Option<String>

The Bluetooth friendly name. This defaults to the system hostname.

class: Option<u32>

The Bluetooth class of device, automatically configured by DMI/ACPI information or provided as static configuration.

bonded: boolicon: Option<String>trusted: boolblocked: boollegacy_pairing: boolmodalias: Option<String>wake_allowed: bool