DiscoveryFilter

Struct DiscoveryFilter 

pub struct DiscoveryFilter {
    pub service_uuids: Vec<Uuid>,
    pub rssi_threshold: Option<i16>,
    pub pathloss_threshold: Option<u16>,
    pub transport: Option<Transport>,
    pub duplicate_data: Option<bool>,
    pub discoverable: Option<bool>,
    pub pattern: Option<String>,
}
A set of filter parameters for discovery. Parameters may be set to None to use the BlueZ defaults.

If no parameters are set then there is a default filter on the RSSI values, where only values which have changed more than a certain amount will be reported.

Fields

service_uuids: Vec<Uuid>

If non-empty, only report devices which advertise at least one of these service UUIDs.

rssi_threshold: Option<i16>

Only report devices with RSSI values greater than the given threshold.

pathloss_threshold: Option<u16>transport: Option<Transport>

The type of scan.

duplicate_data: Option<bool>

Whether to include duplicate advertisements. If this is set to true then there will be an event whenever an advertisement containing manufacturer-specific data for a device is received.

discoverable: Option<bool>

Whether to make the adapter discoverable while discovering.

pattern: Option<String>

Only report devices whose address or name starts with the given pattern.